from bars import *
from bubble import *
from correlation import *
from data import *
from descriptive import *
from gui import *
from histogram import *
from kde import *
from ols import *
from regression import *
from swarm import *
from table import *
from text import *

__version__ = "0.9"